Here is the bulk of the sanitizing.
Almost all occurrences of "bytecode" in the sources have been eliminated.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37913 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Linker/LinkItems.cpp b/lib/Linker/LinkItems.cpp
index 50efe46..e66fa5b 100644
--- a/lib/Linker/LinkItems.cpp
+++ b/lib/Linker/LinkItems.cpp
@@ -7,7 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
 // This file contains routines to handle linking together LLVM bytecode files,
 // and to handle annoying things like static libraries.
 //
 //===----------------------------------------------------------------------===//
@@ -20,7 +20,7 @@
 // LinkItems - This function is the main entry point into linking. It takes a
 // list of LinkItem which indicates the order the files should be linked and
 // how each file should be treated (plain file or with library search). The
 // function only links bytecode and produces a result list of items that are
 // native objects. 
 bool
 Linker::LinkInItems(const ItemList& Items, ItemList& NativeItems) {
@@ -109,7 +109,7 @@
 }
 
 /// LinkLibraries - takes the specified library files and links them into the
 /// main bytecode object file.
 ///
 /// Inputs:
 ///  Libraries  - The list of libraries to link into the module.
@@ -140,11 +140,11 @@
   return false;
 }
 
 /// LinkInFile - opens a bytecode file and links in all objects which
 /// provide symbols that are currently undefined.
 ///
 /// Inputs:
 ///  File - The pathname of the bytecode file.
 ///
 /// Outputs:
 ///  ErrorMessage - A C++ string detailing what error occurred, if any.
@@ -179,7 +179,7 @@
     case sys::Bitcode_FileType:
     case sys::Bytecode_FileType:
     case sys::CompressedBytecode_FileType: {
-      verbose("Linking bytecode file '" + File.toString() + "'");
+      verbose("Linking bitcode file '" + File.toString() + "'");
       std::auto_ptr<Module> M(LoadObject(File));
       if (M.get() == 0)
         return error("Cannot load file '" + File.toString() + "'" + Error);
@@ -208,9 +208,9 @@
 /// or relative pathname, or as a file somewhere in LLVM_LIB_SEARCH_PATH.
 ///
 /// Inputs:
 ///  Files      - A vector of sys::Path indicating the LLVM bytecode filenames
 ///               to be linked.  The names can refer to a mixture of pure LLVM
 ///               bytecode files and archive (ar) formatted files.
 ///
 /// Return value:
 ///  FALSE - No errors.
@@ -7,7 +7,7 @@
 //===----------------------------------------------------------------------===//
 //
-// This file contains routines to handle linking together LLVM bytecode files,
+// This file contains routines to handle linking together LLVM bitcode files,
 // and to handle annoying things like static libraries.
 //
@@ -20,7 +20,7 @@
 // list of LinkItem which indicates the order the files should be linked and
 // how each file should be treated (plain file or with library search). The
-// function only links bytecode and produces a result list of items that are
+// function only links bitcode and produces a result list of items that are
 // native objects. 
 bool
@@ -109,7 +109,7 @@
 
 /// LinkLibraries - takes the specified library files and links them into the
-/// main bytecode object file.
+/// main bitcode object file.
 ///
 /// Inputs:
@@ -140,11 +140,11 @@
 }
 
-/// LinkInFile - opens a bytecode file and links in all objects which
+/// LinkInFile - opens a bitcode file and links in all objects which
 /// provide symbols that are currently undefined.
 ///
@@ -140,11 +140,11 @@
 ///
 /// Inputs:
-///  File - The pathname of the bytecode file.
+///  File - The pathname of the bitcode file.
 ///
 /// Outputs:
@@ -208,9 +208,9 @@
 ///
 /// Inputs:
-///  Files      - A vector of sys::Path indicating the LLVM bytecode filenames
+///  Files      - A vector of sys::Path indicating the LLVM bitcode filenames
 ///               to be linked.  The names can refer to a mixture of pure LLVM
@@ -208,9 +208,9 @@
 ///               to be linked.  The names can refer to a mixture of pure LLVM
-///               bytecode files and archive (ar) formatted files.
+///               bitcode files and archive (ar) formatted files.
 ///
 /// Return value: